@@ -1,7 +1,5 @@
 package Email::Stuff;
 
-=pod
-
 =head1 NAME
 
 Email::Stuff - A more casual approach to creating and sending Email:: emails
@@ -173,18 +171,12 @@ use prefork 'File::Type';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '2.07';
+	$VERSION = '2.08';
 }
 
-
-
-
-
 #####################################################################
 # Constructor and Accessors
 
-=pod
-
 =head2 new
 
 Creates a new, empty, Email::Stuff object.
@@ -212,8 +204,6 @@ sub _self {
 	ref($either) ? $either : $either->new;
 }
 
-=pod
-
 =head2 header_names
 
 Returns, as a list, all of the headers currently set for the Email
@@ -229,8 +219,6 @@ sub headers {
 	shift()->{email}->header_names; ## This is now header_names, headers is depreciated
 }
 
-=pod
-
 =head2 parts
 
 Returns, as a list, the L<Email::MIME> parts for the Email
@@ -248,8 +236,6 @@ sub parts {
 #####################################################################
 # Header Methods
 
-=pod
-
 =head2 header $header => $value
 
 Adds a single named header to the email. Note I said B<add> not set,
@@ -264,8 +250,6 @@ sub header {
 	$self->{email}->header_set(shift, shift) ? $self : undef;
 }
 
-=pod
-
 =head2 to $address
 
 Adds a To: header to the email
@@ -277,8 +261,6 @@ sub to {
 	$self->{email}->header_set(to => shift) ? $self : undef;
 }
 
-=pod
-
 =head2 from $address
 
 Adds (yes ADDS, you only do it once) a From: header to the email
@@ -290,8 +272,6 @@ sub from {
 	$self->{email}->header_set(from => shift) ? $self : undef;
 }
 
-=pod
-
 =head2 cc $address
 
 Adds a Cc: header to the email
@@ -303,8 +283,6 @@ sub cc {
 	$self->{email}->header_set(cc => shift) ? $self : undef;
 }
 
-=pod
-
 =head2 bcc $address
 
 Adds a Bcc: header to the email
@@ -316,8 +294,6 @@ sub bcc {
 	$self->{email}->header_set(bcc => shift) ? $self : undef;
 }
 
-=pod
-
 =head2 subject $text
 
 Adds a subject to the email
@@ -329,15 +305,9 @@ sub subject {
 	$self->{email}->header_set(subject => shift) ? $self : undef;
 }
 
-
-
-
-
 #####################################################################
 # Body and Attachments
 
-=pod
-
 =head2 text_body $body [, $header => $value, ... ]
 
 Sets the text body of the email. Unless specified, all the appropriate
@@ -367,8 +337,6 @@ sub text_body {
 	$self;
 }
 
-=pod
-
 =head2 html_body $body [, $header => $value, ... ]
 
 Set the HTML body of the email. Unless specified, all the appropriate
@@ -397,8 +365,6 @@ sub html_body {
 	$self;
 }
 
-=pod
-
 =head2 attach $contents [, $header => $value, ... ]
 
 Adds an attachment to the email. The first argument is the file contents
@@ -439,8 +405,6 @@ sub attach {
 	$self;
 }
 
-=pod
-
 =head2 attach_file $file
 
 Provides a one-argument method to attach a file that already exists
@@ -487,8 +451,6 @@ sub _slurp {
 	\$source;
 }
 
-=pod
-
 =head2 using $drivername, @options
 
 The C<using> method specifies the L<Email::Send> driver that you want to use to
@@ -525,8 +487,6 @@ sub using {
 #####################################################################
 # Output Methods
 
-=pod
-
 =head2 email
 
 Creates and returns the full L<Email::MIME> object for the email.
@@ -578,8 +538,6 @@ sub _transfer_headers {
         # $_[0] = from, $_[1] = to
         my @headers_move = $_[0]->header_names;
         my @headers_skip = $_[1]->header_names;
-print "HM: @headers_move\n";
-print "HS: @headers_skip\n";
         foreach my $header_name (@headers_move) {
                 next if _any { $_ eq $header_name } @headers_skip;
                 my @values = $_[0]->header($header_name);
@@ -587,8 +545,6 @@ print "HS: @headers_skip\n";
         }
 }
 
-=pod
-
 =head2 as_string
 
 Returns the string form of the email. Identical to (and uses behind the
@@ -600,8 +556,6 @@ sub as_string {
 	shift()->email->as_string;
 }
 
-=pod
-
 =head2 send
 
 Sends the email via L<Email::Send>.
@@ -626,8 +580,6 @@ sub _options {
 	@{$self->{send_using}}[1 .. $options];
 }
 
-=pod
-
 =head2 mailer
 
 If you need to interact with it directly, the C<mailer> method
@@ -671,15 +623,17 @@ sub Email   { shift->email(@_)   }
 
 1;
 
-=pod
-
 =head1 TO DO
 
-- Fix a number of bugs still likely to exist
+=over 4
 
-- Write some proper unit tests. Write ANY unit tests
+=item * Fix a number of bugs still likely to exist
 
-- Add any additional small bit of automation that arn't too expensive
+=item * Write more tests.
+
+=item * Add any additional small bit of automation that arn't too expensive
+
+=back
 
 =head1 SUPPORT
 
@@ -687,10 +641,10 @@ All bugs should be filed via the CPAN bug tracker at
 
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Email-Stuff>
 
-For other issues, or commercial enhancement or support, contact the author.
-
 =head1 AUTHORS
 
+B<Current maintainer>: Ricardo Signes C<rjbs@cpan.org>
+
 Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
